#!/bin/sh
PRIMER3_DIR=/usr/local/bin
export PRIMER3_DIR
MCPRIMERS_DIR=~/desktop/Bio-MCPrimers-2.4
export MCPRIMERS_DIR
perl mcprimers_gui.pl

